#include "resource.h"

std::map<std::basic_string<TCHAR>,Texture>	Resource::m_Textures;	// eNX`
std::map<std::basic_string<TCHAR>,Effect>	Resource::m_Effects;	// GtFNg
std::map<std::basic_string<TCHAR>,MODEL>	Resource::m_Models;		// f

bool Resource::LoadTexture(IDirect3DDevice9* pD3DDevice,const TCHAR* FileName)
{
	m_Textures.insert(std::make_pair(FileName,Texture()));
	if(!m_Textures[FileName].Create(FileName,pD3DDevice)){
		m_Textures.erase(FileName);
		return false;
	}

	return true;
}

bool Resource::LoadTexture(IDirect3DDevice9* pD3DDevice,const TCHAR* FileName,int Width,int Height,DWORD ColorKey,D3DFORMAT Format)
{
	m_Textures.insert(std::make_pair(FileName,Texture()));
	if(!m_Textures[FileName].Create(FileName,pD3DDevice,Width,Height,ColorKey,Format)){
		m_Textures.erase(FileName);
		return false;
	}

	return true;
}

bool Resource::LoadEffect(IDirect3DDevice9* pD3DDevice,const TCHAR* FileName)
{
	m_Effects.insert(std::make_pair(FileName,Effect()));
	if(!m_Effects[FileName].Create(pD3DDevice,FileName)){
		m_Textures.erase(FileName);
		return false;
	}

	return true;
}

bool Resource::LoadModel(IDirect3DDevice9* pD3DDevice,const TCHAR* FileName,int ModelFile)
{
	m_Models.insert(std::make_pair(FileName,MODEL()));
	bool isSucceeded = false;
	switch(ModelFile)
	{
	case XFILE:
		isSucceeded = XFileLoader::Load(FileName,&m_Models[FileName]);
		break;
	}

	// ǂݍݐ
	if(!isSucceeded){
		m_Models.erase(FileName);
		return false;
	}

	// eNX`ǂݍ
	for(unsigned int i = 0;i < m_Models[FileName].Meshs.size();++i){
		for(unsigned int j = 0;j < m_Models[FileName].Meshs[i].Materials.size();++j){
			const TEXTURE& tex = m_Models[FileName].Meshs[i].Materials[j].Texture;
			if(tex.ColorTexName.size() > 0)
				Resource::LoadTexture(pD3DDevice,tex.ColorTexName.c_str());
			if(tex.BumpTexName.size() > 0)
				Resource::LoadTexture(pD3DDevice,tex.BumpTexName.c_str());
			if(tex.NormalTexName.size() > 0)
				Resource::LoadTexture(pD3DDevice,tex.NormalTexName.c_str());
			if(tex.AlphaTexName.size() > 0)
				Resource::LoadTexture(pD3DDevice,tex.AlphaTexName.c_str());
		}
	}

	return true;
}

Texture* Resource::GetTexture(const TCHAR* TextureName)
{
	if(m_Textures.find(TextureName) == m_Textures.end())
		return NULL;

	return &m_Textures[TextureName];
}
Effect* Resource::GetEffect(const TCHAR* EffectName)
{
	if(m_Effects.find(EffectName) == m_Effects.end())
		return NULL;

	return &m_Effects[EffectName];
}
MODEL* Resource::GetModel(const TCHAR* ModelName)
{
	if(m_Models.find(ModelName) == m_Models.end())
		return NULL;

	return &m_Models[ModelName];
}
